@@ -82,7 +82,7 @@ SQL::Easy give you easy access to data stored in databases using well known SQL
 use strict;
 use warnings;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 use DBI;
 
@@ -337,10 +337,12 @@ sub _reconnect_if_needed {
 # Gets hashref with connection parameters and returns db
 sub _get_connection {
     my ($s) = @_;
-    my $dsn = "DBI:mysql:database=" . $s->{db} . ";host=" . $s->{host} . ";port=" . $s->{port} . ";mysql_enable_utf8=1";
-    my $dbh = DBI->connect($dsn, $s->{user}, $s->{password}, { RaiseError => 1,
+    my $dsn = "DBI:mysql:database=" . $s->{db} . ";host=" . $s->{host} . ";port=" . $s->{port};
+    my $dbh = DBI->connect($dsn, $s->{user}, $s->{password}, {
+        RaiseError => 1,
         PrintError => 0,
         mysql_auto_reconnect => 0,
+        mysql_enable_utf8 => 1,
     });
     return $dbh;
 }
@@ -372,7 +374,7 @@ sub _check_connection {
 
 Ivan Bessarabov, C<< <ivan@bessarabov.ru> >>
 
-=head2 SOURCE CODE 
+=head1 SOURCE CODE 
 
 The source code for this module is hosted on GitHub http://github.com/bessarabov/SQL-Easy
 
